import React from "react";
import styled from "styled-components";
import LobbyPlayerList from "./LobbyPlayerList";
import HeaderAndFooter from "../../util/HeaderAndFooter";
import ClickToCopy from "../../util/ClickToCopy";
import { useGameJoined, useGameId } from "../../../domain/gameStore";
import JoinForm from "./JoinForm";
import LobbyInfo from "./LobbyInfo";

const InfoContainer = styled.div`
  flex: 3;
  align-self: center;

  display: flex;
  flex-flow: column nowrap;
  justify-content: center;
  align-items: center;
`

const PageContainer = styled.div`
  flex: 1;
  display: flex;
  flex-flow: row nowrap;
  justify-content: space-between;
  align-items: flex-start;
`

const Label = styled.span`
  padding: 0.2em;
`

const getUrl = gameId => {
  const u = new URL(window.location.href);
  u.searchParams.append("join", gameId);
  return u.href;
}

const Lobby = ({ onStart }) => {
  const gameId = useGameId();
  const joined = useGameJoined();

  return (
    <HeaderAndFooter>
      <PageContainer>
        <InfoContainer>
          {
            joined
              ? <LobbyInfo onStart={onStart}/>
              : <JoinForm />
          }
          <Label>Use this link to invite other players:</Label>
          <Label><ClickToCopy text={getUrl(gameId)} /></Label>
        </InfoContainer>
        <LobbyPlayerList/>
      </PageContainer>
    </HeaderAndFooter>
  )
};

export default Lobby;
